==> igniteui-react-core-18.2.0-beta.0.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescriptionObjectDescriptionMetadata } from "./PropertyEditorDescriptionObjectDescriptionMetadata";
import { PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata } from "./PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata";
import { PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata } from "./PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata";
import { PropertyEditorPropertyDescriptionDescription } from "./PropertyEditorPropertyDescriptionDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionDescriptionMetadata.c(PropertyEditorPropertyDescriptionDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.ab(PropertyEditorPropertyDescriptionDescriptionMetadata.a);
            PropertyEditorDescriptionObjectDescriptionMetadata.d(a);
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.d(a);
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.d(a);
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("PropertyPath", "String");
            a.item("Label", "String");
            a.item("ValueType", "ExportedType:string:PropertyEditorValueType");
            a.item("ValueType@names", "Unhandled;Number;StringValue;Date;Brush;Color;BrushCollection;Boolean1;SubType;Collection;Array;Point;Size;Rect;ColorCollection;EnumValue;MethodRef;EventRef;DataRef;TimeSpan;Button;Slider;TemplateRef");
            a.item("PropertyDescriptionType", "String");
            a.item("ShouldOverrideDefaultEditor", "Boolean");
            a.item("ElementDescriptionType", "String");
            a.item("DropDownNames", "Array:string");
            a.item("DropDownValues", "Array:string");
            a.item("PrimitiveValue", "Unknown");
            a.item("Min", "Number:double");
            a.item("EditorWidth", "Number:double");
            a.item("LabelWidth", "Number:double");
            a.item("Max", "Number:double");
            a.item("Step", "Number:double");
            a.item("ComplexValue", "ExportedType:PropertyEditorDescriptionObject");
            a.item("ComplexValues", "Collection:PropertyEditorDescriptionObject:PropertyEditorDescriptionObjectCollection:PropertyEditorDescriptionObject");
            a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
            a.item("ButtonClickedRef", "EventRef::buttonClicked");
            a.item("ChangedRef", "EventRef::changed");
            a.item("TargetPropertyUpdatingRef", "EventRef::targetPropertyUpdating");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionDescriptionMetadata.b(a);
            a.ad("PropertyEditorPropertyDescription", () => new PropertyEditorPropertyDescriptionDescription());
            a.ac("PropertyEditorPropertyDescription", PropertyEditorPropertyDescriptionDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionDescriptionMetadata, 'PropertyEditorPropertyDescriptionDescriptionMetadata');
    PropertyEditorPropertyDescriptionDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.0.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescriptionObjectDescriptionMetadata } from "./PropertyEditorDescriptionObjectDescriptionMetadata";
import { PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata } from "./PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata";
import { PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata } from "./PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata";
import { PropertyEditorPropertyDescriptionDescription } from "./PropertyEditorPropertyDescriptionDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionDescriptionMetadata.c(PropertyEditorPropertyDescriptionDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.ac(PropertyEditorPropertyDescriptionDescriptionMetadata.a);
            PropertyEditorDescriptionObjectDescriptionMetadata.d(a);
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.d(a);
            PropertyEditorPropertyDescriptionChangedEventArgsDescriptionMetadata.d(a);
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("PropertyPath", "String");
            a.item("Label", "String");
            a.item("ValueType", "ExportedType:string:PropertyEditorValueType");
            a.item("ValueType@names", "Unhandled;Number;StringValue;Date;Brush;Color;BrushCollection;Boolean1;SubType;Collection;Array;Point;Size;Rect;ColorCollection;EnumValue;MethodRef;EventRef;DataRef;TimeSpan;Button;Slider;TemplateRef;DoubleCollection");
            a.item("PropertyDescriptionType", "String");
            a.item("ShouldOverrideDefaultEditor", "Boolean");
            a.item("ElementDescriptionType", "String");
            a.item("DropDownNames", "Array:string");
            a.item("DropDownValues", "Array:string");
            a.item("PrimitiveValue", "Unknown");
            a.item("Min", "Number:double");
            a.item("EditorWidth", "Number:double");
            a.item("LabelWidth", "Number:double");
            a.item("Max", "Number:double");
            a.item("Step", "Number:double");
            a.item("ComplexValue", "ExportedType:PropertyEditorDescriptionObject");
            a.item("ComplexValues", "Collection:PropertyEditorDescriptionObject:PropertyEditorDescriptionObjectCollection:PropertyEditorDescriptionObject");
            a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
            a.item("ButtonClickedRef", "EventRef::buttonClicked");
            a.item("ChangedRef", "EventRef::changed");
            a.item("TargetPropertyUpdatingRef", "EventRef::targetPropertyUpdating");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionDescriptionMetadata.b(a);
            a.ae("PropertyEditorPropertyDescription", () => new PropertyEditorPropertyDescriptionDescription());
            a.ad("PropertyEditorPropertyDescription", PropertyEditorPropertyDescriptionDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionDescriptionMetadata, 'PropertyEditorPropertyDescriptionDescriptionMetadata');
    PropertyEditorPropertyDescriptionDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionDescriptionMetadata;
})();
